<?php

namespace App\Repository;

use App\Entity\Announcement;
use App\Entity\Intern;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;

/**
 * @extends ServiceEntityRepository<Announcement>
 */
class AnnouncementRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Announcement::class);
    }

    public function searchAnnouncements(?string $companyName, ?string $location, ?string $category): array
    {
        $queryBuilder = $this->createQueryBuilder('a')->InnerJoin('a.company', 'c');

        if ($companyName) {
            $queryBuilder->andWhere('c.name LIKE :companyName')
                ->setParameter('companyName', '%' . $companyName . '%');
        }

        if ($location) {
            $queryBuilder->andWhere('c.address LIKE :location')
                ->setParameter('location', '%' . $location . '%');
        }

        if ($category) {
            $queryBuilder->andWhere('a.title LIKE :category OR a.description LIKE :category')
                ->setParameter('category', '%' . $category . '%');
        }

        return $queryBuilder->getQuery()->getResult();
    }

    public function findFavoritesByIntern(Intern $intern): array
    {
        return $this->createQueryBuilder('a')
            ->innerJoin('a.favoritesInterns', 'fav')
            ->andWhere('fav.intern = :intern')
            ->setParameter('intern', $intern)
            ->getQuery()
            ->getResult();
    }
}
